@@ -68,6 +68,13 @@ extern "C"
 #include <KCddb/Client>
 #include <KCompactDisc/KCompactDisc>
 
+// Pseudo plugin class to embed metadata
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.audiocd" FILE "audiocd.json")
+};
+
 using namespace KIO;
 
 #define CDDB_INFORMATION I18N_NOOP("CDDB Information")
@@ -480,7 +487,7 @@ void AudioCDProtocol::get(const QUrl & url)
 		for ( it = d->cddbList.begin(); it != d->cddbList.end(); ++it ){
 			if(count == choice){
 				mimeType(QLatin1String( "text/html" ));
-				data(QByteArray( (*it).toString().toUtf8() ));
+				data( (*it).toString().toUtf8() );
 				// send an empty QByteArray to signal end of data.
 				data(QByteArray());
 				finished();
@@ -1273,3 +1280,5 @@ void paranoiaCallback(long, int function)
 	}
 }
 
+// needed for JSON file embedding
+#include "audiocd.moc"
